/*******************************************************************************
 * Copyright (c) 2013, Perforce Software
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package com.perforce.search.model;

import java.util.List;

import org.codehaus.jackson.map.annotate.JsonDeserialize;

import com.perforce.search.model.impl.SearchModelImpl;

@JsonDeserialize(as = SearchModelImpl.class)
public interface SearchModel {

    public enum ResultFormat {
	SIMPLE, DETAILED,
    };

    /*
     * When not authenticated, username and ticket|password are required
     */
    String getUserId();

    String getTicket();

    /*
     * Raw data query string
     */
    String getQueryRaw();

    /*
     * Query as it will be sent to search engine
     */
    String getQueryProcessed();

    /*
     * Limit to paths that start with any of these
     */
    List<String> getPaths();

    /*
     * start row, row count
     */
    int getStartRow();

    int getRowCount();

    /*
     * A list of specific fields to search, e.g. depotpath, author, etc.
     */
    SearchField[] getSearchFields();

    /*
     * Result format: simple file list or detailed
     */
    ResultFormat getResultFormat();
}
